==> kubernetes-model-flowcontrol-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/SubjectFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SubjectFluent<A extends SubjectFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildGroup instead.
   * @return The buildable object.
   */
  @Deprecated
  public GroupSubject getGroup();
  public GroupSubject buildGroup();
  public A withGroup(GroupSubject group);
  public Boolean hasGroup();
  public A withNewGroup(String name);
  public SubjectFluent.GroupNested<A> withNewGroup();
  public SubjectFluent.GroupNested<A> withNewGroupLike(GroupSubject item);
  public SubjectFluent.GroupNested<A> editGroup();
  public SubjectFluent.GroupNested<A> editOrNewGroup();
  public SubjectFluent.GroupNested<A> editOrNewGroupLike(GroupSubject item);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildServiceAccount instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceAccountSubject getServiceAccount();
  public ServiceAccountSubject buildServiceAccount();
  public A withServiceAccount(ServiceAccountSubject serviceAccount);
  public Boolean hasServiceAccount();
  public A withNewServiceAccount(String name,String namespace);
  public SubjectFluent.ServiceAccountNested<A> withNewServiceAccount();
  public SubjectFluent.ServiceAccountNested<A> withNewServiceAccountLike(ServiceAccountSubject item);
  public SubjectFluent.ServiceAccountNested<A> editServiceAccount();
  public SubjectFluent.ServiceAccountNested<A> editOrNewServiceAccount();
  public SubjectFluent.ServiceAccountNested<A> editOrNewServiceAccountLike(ServiceAccountSubject item);
  
  /**
   * This method has been deprecated, please use method buildUser instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserSubject getUser();
  public UserSubject buildUser();
  public A withUser(UserSubject user);
  public Boolean hasUser();
  public A withNewUser(String name);
  public SubjectFluent.UserNested<A> withNewUser();
  public SubjectFluent.UserNested<A> withNewUserLike(UserSubject item);
  public SubjectFluent.UserNested<A> editUser();
  public SubjectFluent.UserNested<A> editOrNewUser();
  public SubjectFluent.UserNested<A> editOrNewUserLike(UserSubject item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface GroupNested<N> extends Nested<N>,GroupSubjectFluent<SubjectFluent.GroupNested<N>>{
    public N and();
    public N endGroup();
    
  }
  public interface ServiceAccountNested<N> extends Nested<N>,ServiceAccountSubjectFluent<SubjectFluent.ServiceAccountNested<N>>{
    public N and();
    public N endServiceAccount();
    
  }
  public interface UserNested<N> extends Nested<N>,UserSubjectFluent<SubjectFluent.UserNested<N>>{
    public N and();
    public N endUser();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/SubjectFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SubjectFluent<A extends SubjectFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildGroup instead.
   * @return The buildable object.
   */
  @Deprecated
  public GroupSubject getGroup();
  public GroupSubject buildGroup();
  public A withGroup(GroupSubject group);
  public Boolean hasGroup();
  public A withNewGroup(String name);
  public SubjectFluent.GroupNested<A> withNewGroup();
  public SubjectFluent.GroupNested<A> withNewGroupLike(GroupSubject item);
  public SubjectFluent.GroupNested<A> editGroup();
  public SubjectFluent.GroupNested<A> editOrNewGroup();
  public SubjectFluent.GroupNested<A> editOrNewGroupLike(GroupSubject item);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildServiceAccount instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceAccountSubject getServiceAccount();
  public ServiceAccountSubject buildServiceAccount();
  public A withServiceAccount(ServiceAccountSubject serviceAccount);
  public Boolean hasServiceAccount();
  public A withNewServiceAccount(String name,String namespace);
  public SubjectFluent.ServiceAccountNested<A> withNewServiceAccount();
  public SubjectFluent.ServiceAccountNested<A> withNewServiceAccountLike(ServiceAccountSubject item);
  public SubjectFluent.ServiceAccountNested<A> editServiceAccount();
  public SubjectFluent.ServiceAccountNested<A> editOrNewServiceAccount();
  public SubjectFluent.ServiceAccountNested<A> editOrNewServiceAccountLike(ServiceAccountSubject item);
  
  /**
   * This method has been deprecated, please use method buildUser instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserSubject getUser();
  public UserSubject buildUser();
  public A withUser(UserSubject user);
  public Boolean hasUser();
  public A withNewUser(String name);
  public SubjectFluent.UserNested<A> withNewUser();
  public SubjectFluent.UserNested<A> withNewUserLike(UserSubject item);
  public SubjectFluent.UserNested<A> editUser();
  public SubjectFluent.UserNested<A> editOrNewUser();
  public SubjectFluent.UserNested<A> editOrNewUserLike(UserSubject item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface GroupNested<N> extends Nested<N>,GroupSubjectFluent<SubjectFluent.GroupNested<N>>{
    public N and();
    public N endGroup();
    
  }
  public interface ServiceAccountNested<N> extends Nested<N>,ServiceAccountSubjectFluent<SubjectFluent.ServiceAccountNested<N>>{
    public N and();
    public N endServiceAccount();
    
  }
  public interface UserNested<N> extends Nested<N>,UserSubjectFluent<SubjectFluent.UserNested<N>>{
    public N and();
    public N endUser();
    
  }
  
}
